<h1 align="center">
    <div>
        <img src="https://raw.githubusercontent.com/FormingWorlds/PROTEUS/main/docs/assets/PROTEUS_white.png#gh-light-mode-only" style="vertical-align: middle;" width="60%"/>
        <img src="https://raw.githubusercontent.com/FormingWorlds/PROTEUS/main/docs/assets/PROTEUS_black.png#gh-dark-mode-only" style="vertical-align: middle;" width="60%"/>
    </div>
</h1>

<p align="center">
  <a href="https://github.com/FormingWorlds/PROTEUS/actions/workflows/tests.yaml">
    <img src="https://github.com/FormingWorlds/PROTEUS/actions/workflows/tests.yaml/badge.svg">
  </a>
  <a href="https://fwl-proteus.readthedocs.io/en/latest/">
    <img src="https://readthedocs.org/projects/fwl-proteus/badge/?version=latest">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0">
    <img src="https://img.shields.io/badge/License-Apache_2.0-blue.svg">
  </a>
  <a href="https://github.com/FormingWorlds/PROTEUS/actions/workflows/tests.yaml">
    <img src="https://gist.githubusercontent.com/stefsmeets/b4ee7dab92e20644bcb3a5ad09f71165/raw/covbadge.svg">
  </a>
  <a href="https://agupubs.onlinelibrary.wiley.com/doi/10.1029/2024JE008576"><img src="https://img.shields.io/badge/DOI-10.1029%2F2024JE008576-blue"></a>
</p>

<b>PROTEUS</b> (/ˈproʊtiəs, PROH-tee-əs) is a modular Python framework that simulates the coupled evolution of the atmospheres and interiors of rocky planets and exoplanets. Inspired by the Greek god of elusive sea change, who could change his form at will, PROTEUS is designed to be flexible and adaptable to a wide range of planetary environments. It can foretell the future, but answers only to those who are capable of asking the right questions.<br>

More information can be found on the [documentation](https://fwl-proteus.readthedocs.io/en/latest/index.html) pages:

* [model description](https://fwl-proteus.readthedocs.io/en/latest/model.html)
* [installation guide](https://fwl-proteus.readthedocs.io/en/latest/installation.html)
* [usage guide](https://fwl-proteus.readthedocs.io/en/latest/usage.html)
* [contributing guide](https://fwl-proteus.readthedocs.io/en/latest/CONTRIBUTING.html)

You can find help on the [discussions page](https://github.com/orgs/FormingWorlds/discussions) or by [contacting the developers](https://fwl-proteus.readthedocs.io/en/latest/contact.html) directly.

If you make use of PROTEUS, please reference the papers outlined in the [bibliography](https://fwl-proteus.readthedocs.io/en/latest/bibliography.html).
